@@ -1,4 +1,4 @@
-#  Copyright (c) 2018-2019 by Rocky Bernstein
+#  Copyright (c) 2018-2020 by Rocky Bernstein
 #
 #  This program is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@ allow running on Python 2.
 """
 
 import re, sys, types
-from xdis import PYTHON3
+from xdis.version_info import PYTHON3
 
 from collections import namedtuple
 
@@ -64,30 +64,40 @@ def findlinestarts(code, dup_lines=False):
     """Find the offsets in a byte code which are start of lines in the source.
 
     Generate pairs (offset, lineno) as described in Python/compile.c.
-
     """
-    if not isinstance(code.co_lnotab, str):
-        byte_increments = list(code.co_lnotab[0::2])
-        line_increments = list(code.co_lnotab[1::2])
-    else:
-        byte_increments = [ord(c) for c in code.co_lnotab[0::2]]
-        line_increments = [ord(c) for c in code.co_lnotab[1::2]]
+    lineno_table = code.co_lnotab
 
-    lastlineno = None
-    lineno = code.co_firstlineno
-    offset = 0
-    for byte_incr, line_incr in zip(byte_increments, line_increments):
-        if byte_incr:
-            if (lineno != lastlineno or dup_lines and 0 < byte_incr < 255):
-                yield (offset, lineno)
-                lastlineno = lineno
+    if isinstance(lineno_table, dict):
+        # We have an uncompressed line-number table
+        # The below could be done with a Python generator, but
+        # we want to be Python 2.x compatible.
+        for addr, lineno in lineno_table.items():
+            yield addr, lineno
+        # For 3.8 we have to fall through to the return rather
+        # than add raise StopIteration
+    else:
+        if not isinstance(code.co_lnotab, str):
+            byte_increments = list(code.co_lnotab[0::2])
+            line_increments = list(code.co_lnotab[1::2])
+        else:
+            byte_increments = [ord(c) for c in code.co_lnotab[0::2]]
+            line_increments = [ord(c) for c in code.co_lnotab[1::2]]
+
+        lastlineno = None
+        lineno = code.co_firstlineno
+        offset = 0
+        for byte_incr, line_incr in zip(byte_increments, line_increments):
+            if byte_incr:
+                if (lineno != lastlineno or dup_lines and 0 < byte_incr < 255):
+                    yield (offset, lineno)
+                    lastlineno = lineno
+                    pass
+                offset += byte_incr
                 pass
-            offset += byte_incr
-            pass
-        lineno += line_incr
-    if (lineno != lastlineno or
-        (dup_lines and 0 < byte_incr < 255)):
-        yield (offset, lineno)
+            lineno += line_incr
+        if (lineno != lastlineno or
+            (dup_lines and 0 < byte_incr < 255)):
+            yield (offset, lineno)
 
 def offset2line(offset, linestarts):
     """linestarts is expected to be a *list) of (offset, line number)
@@ -310,9 +320,11 @@ def get_instructions_bytes(bytecode, opc, varnames=None, names=None, constants=N
 
         opname = opc.opname[op]
         inst_size = op_size(op, opc) + (extended_arg_count * extended_arg_size)
+        fallthrough = op not in opc.nofollow
         yield Instruction(opname, op, optype, inst_size, arg, argval, argrepr,
                           has_arg, offset, starts_line, is_jump_target,
-                          extended_arg_count != 0)
+                          extended_arg_count != 0, )
+                          # fallthrough)
         extended_arg_count = extended_arg_count + 1 if op == opc.EXTENDED_ARG else 0
 
 def op_has_argument(op, opc):
@@ -339,6 +351,7 @@ op_size = instruction_size
 
 _Instruction = namedtuple("_Instruction",
      "opname opcode optype inst_size arg argval argrepr has_arg offset starts_line is_jump_target has_extended_arg")
+     # "opname opcode optype inst_size arg argval argrepr has_arg offset starts_line is_jump_target has_extended_arg fallthrough")
 
 class Instruction(_Instruction):
     """Details for a bytecode operation
@@ -364,6 +377,9 @@ class Instruction(_Instruction):
                           Otherwise False
          has_extended_arg - True if the instruction was built from EXTENDED_ARG
                             opcodes
+         fallthrough - True if the instruction can (not must) fall through to the next
+                       instruction. Note conditionals are in this category, but
+                       returns, raise, and unconditional jumps are not
     """
     # FIXME: remove has_arg from initialization but keep it as a field.
 
@@ -488,13 +504,19 @@ class Bytecode(object):
     def __init__(self, x, opc, first_line=None, current_offset=None,
                  dup_lines=False):
         self.codeobj = co = get_code_object(x)
-        if first_line is None:
-            self.first_line = co.co_firstlineno
-            self._line_offset = 0
-        else:
-            self.first_line = first_line
-            self._line_offset = first_line - co.co_firstlineno
-        self._cell_names = co.co_cellvars + co.co_freevars
+        self._line_offset = 0
+        self._cell_names = ()
+        if opc.version > 1.5:
+            if first_line is None:
+                self.first_line = co.co_firstlineno
+            else:
+                self.first_line = first_line
+                self._line_offset = first_line - co.co_firstlineno
+            if opc.version > 2.0:
+                self._cell_names = co.co_cellvars + co.co_freevars
+                pass
+            pass
+
         self._linestarts = dict(opc.findlinestarts(co, dup_lines=dup_lines))
         self._original_object = x
         self.opc = opc
@@ -531,10 +553,17 @@ class Bytecode(object):
         else:
             offset = -1
         output = StringIO()
+        if self.opc.version > 2.0:
+            cells = self._cell_names
+            linestarts = self._linestarts
+        else:
+            cells = None
+            linestarts = None
+
         self.disassemble_bytes(co.co_code, varnames=co.co_varnames,
                                names=co.co_names, constants=co.co_consts,
-                               cells=self._cell_names,
-                               linestarts=self._linestarts,
+                               cells=cells,
+                               linestarts=linestarts,
                                line_offset=self._line_offset,
                                file=output,
                                lasti=offset,
