@@ -1,4 +1,4 @@
-# (C) Copyright 2018-2019 by Rocky Bernstein
+# (C) Copyright 2018-2020 by Rocky Bernstein
 #
 #  This program is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU General Public License
@@ -29,8 +29,8 @@ there). Details of the format may change between Python versions.
 
 import types, struct
 
-from xdis import PYTHON_VERSION, PYTHON3
-from xdis.code import Code2, Code2Compat, Code3, Code3Compat
+from xdis.version_info import PYTHON_VERSION, PYTHON3
+from xdis.codetype import Code2, Code3
 
 try:
     intern
@@ -328,7 +328,6 @@ class _Marshaller:
         return
 
     dispatch[Code2] = dump_code2
-    dispatch[Code2Compat] = dump_code2
 
     # FIXME: will probably have to adjust similar to how we
     # adjusted dump_code2
@@ -351,7 +350,6 @@ class _Marshaller:
         self.dump(x.co_lnotab)
 
     dispatch[Code3] = dump_code3
-    dispatch[Code3Compat] = dump_code3
 
     try:
         if PYTHON3:
@@ -948,9 +946,10 @@ class _FastUnmarshaller:
         firstlineno = _r_long(self)
         lnotab = self.load()
         if PYTHON3:
+            if isinstance(name, bytes):
+                name = name.decode()
             return Code2(
                 argcount,
-                0,
                 nlocals,
                 stacksize,
                 flags,
