@@ -1,4 +1,4 @@
-# (C) Copyright 2016-2017, 2019 by Rocky Bernstein
+# (C) Copyright 2016-2017, 2019-2020 by Rocky Bernstein
 #
 #  This program is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU General Public License
@@ -22,9 +22,8 @@ of stack usage.
 
 from xdis.opcodes.base import(
     def_op, finalize_opcodes,
-    format_extended_arg36,
     init_opdata, jrel_op, name_op,
-    nargs_op, rm_op, varargs_op,
+    nargs_op, rm_op, store_op, varargs_op,
     update_pj3
     )
 
@@ -89,7 +88,7 @@ rm_op(l, 'CALL_FUNCTION_VAR_KW', 142)
 
 
 # These are new since Python 3.6
-name_op(l,    'STORE_ANNOTATION', 127) # Index in name list
+store_op(l,    'STORE_ANNOTATION', 127, is_type="name") # Index in name list
 jrel_op(l,    'SETUP_ASYNC_WITH', 154)
 def_op(l,     'FORMAT_VALUE',     155)
 varargs_op(l, 'BUILD_CONST_KEY_MAP', 156, -1, 1) # TOS is count of kwargs
@@ -128,7 +127,21 @@ def format_value_flags(flags):
         # empty fmt_spec.
         return ''
 
+def format_extended_arg36(arg):
+    return str(arg * (1 << 8))
+
+def format_CALL_FUNCTION_EX(flags):
+    str = ""
+    if flags & 0x01:
+        str = "keyword args"
+    return str
+
+def format_CALL_FUNCTION_KW(argc):
+    return "%d total positional and keyword args" % argc
+
 opcode_arg_fmt = {
+    'CALL_FUNCTION_KW': format_CALL_FUNCTION_KW,
+    'CALL_FUNCTION_EX': format_CALL_FUNCTION_EX,
     'MAKE_FUNCTION': format_MAKE_FUNCTION_arg,
     'FORMAT_VALUE': format_value_flags,
     'EXTENDED_ARG': format_extended_arg36
