@@ -1,4 +1,4 @@
-# Copyright (c) 2015-2019 by Rocky Bernstein
+# Copyright (c) 2015-2020 by Rocky Bernstein
 # Copyright (c) 2000-2002 by hartmut Goebel <h.goebel@crazy-compilers.com>
 #
 #  This program is free software; you can redistribute it and/or
@@ -15,23 +15,23 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-"""
-CPython magic- and version-independent Python object
+"""CPython magic- and version-independent Python object
 deserialization (unmarshal).
 
 This is needed when the bytecode extracted is from
 a different version than the currently-running Python.
 
-When the two are the same, you can simply use Python's built-in marshal.loads()
-to produce a code object
+When the running interpreter and the read-in bytecode are the same,
+you can simply use Python's built-in marshal.loads() to produce a code
+object
 """
 
 import sys, types
 from struct import unpack
 
-from xdis.magics import PYTHON_MAGIC_INT, IS_PYPY3
-from xdis.code import Code2, Code3, Code38, Code2Compat
-from xdis import PYTHON3, PYTHON_VERSION, IS_PYPY
+from xdis.magics import magic_int2float, PYTHON_MAGIC_INT, IS_PYPY3
+from xdis.codetype import to_portable
+from xdis.version_info import PYTHON3, PYTHON_VERSION, IS_PYPY
 
 # FIXME: When working from Python3 bytecode in Python2, we need
 # to distinguish types.
@@ -116,56 +116,60 @@ def load_code(fp, magic_int, code_objects={}):
 
 def load_code_type(fp, magic_int, bytes_for_s=False, code_objects={}):
     # FIXME: use tables to simplify this?
-    # Python [1.0 .. 2.2)
+    # FIXME: Python 1.0 .. 1.3 isn't well known
 
+    # FIXME: REMOVE THIS and replace using "versions"
     v10_to_12 = magic_int in (39170, 39171)
-
-    # FIXME: find out what magics were for 1.3
     v13_to_22 = magic_int in (11913, 5892, 20121, 50428, 50823, 60202, 60717)
     v11_to_14 = magic_int in (39170, 39171, 11913, 5892)
-
-    # Python [1.5 .. 2.2)
     v15_to_22 = magic_int in (20121, 50428, 50823, 60202, 60717)
     v13_to_20 = magic_int in (11913, 5892, 20121, 50428, 50823)
     v21_to_27 = not v13_to_20 and 60202 <= magic_int <= 63000
 
-    if v13_to_22:
-        co_argcount = unpack("<h", fp.read(2))[0]
-    elif v10_to_12:
-        co_argcount = 0
-    else:
-        co_argcount = unpack("<i", fp.read(4))[0]
+    version = magic_int2float(magic_int)
 
+    if version >= 2.3:
+        co_argcount = unpack("<i", fp.read(4))[0]
+    elif version >= 1.3:
+        co_argcount = unpack("<h", fp.read(2))[0]
+    else:
+        co_argcount = 0
+
+    # FIXME:
+    # Note we do this by magic_int, not version which is *not*
+    # 3.8
     if magic_int in (3412, 3413, 3422):
         co_posonlyargcount = unpack("<i", fp.read(4))[0]
+    if version >= 3.8:
+        co_posonlyargcount = 0
     else:
         co_posonlyargcount = None
 
-    if ((3020 < magic_int < 20121) or magic_int in (64, 160, 112, 192)) and not v11_to_14:
+    if version >= 3.0:
         kwonlyargcount = unpack("<i", fp.read(4))[0]
     else:
         kwonlyargcount = 0
 
-    if v13_to_22:
-        co_nlocals = unpack("<h", fp.read(2))[0]
-    elif v10_to_12:
-        co_nlocals = 0
-    else:
+    if version >= 2.3:
         co_nlocals = unpack("<i", fp.read(4))[0]
-
-    if v15_to_22:
-        co_stacksize = unpack("<h", fp.read(2))[0]
-    elif v11_to_14 or v10_to_12:
-        co_stacksize = 0
+    elif version >= 1.3:
+        co_nlocals = unpack("<h", fp.read(2))[0]
     else:
+        co_nlocals = 0
+
+    if version >= 2.3:
         co_stacksize = unpack("<i", fp.read(4))[0]
-
-    if v13_to_22:
-        co_flags = unpack("<h", fp.read(2))[0]
-    elif v10_to_12:
-        co_flags = 0
+    elif version >= 1.5:
+        co_stacksize = unpack("<h", fp.read(2))[0]
     else:
+        co_stacksize = 0
+
+    if version >= 2.3:
         co_flags = unpack("<i", fp.read(4))[0]
+    elif version >= 1.3:
+        co_flags = unpack("<h", fp.read(2))[0]
+    else:
+        co_flags = 0
 
     co_code = load_code_internal(
         fp, magic_int, bytes_for_s=True, code_objects=code_objects
@@ -173,13 +177,12 @@ def load_code_type(fp, magic_int, bytes_for_s=False, code_objects={}):
     co_consts = load_code_internal(fp, magic_int, code_objects=code_objects)
     co_names = load_code_internal(fp, magic_int, code_objects=code_objects)
 
-    # FIXME: only if >= 1.3
-    if v10_to_12:
-        co_varnames = []
-    else:
+    if version >= 1.3:
         co_varnames = load_code_internal(fp, magic_int, code_objects=code_objects)
+    else:
+        co_varnames = []
 
-    if not (v13_to_20 or v10_to_12):
+    if version >= 2.0:
         co_freevars = load_code_internal(fp, magic_int, code_objects=code_objects)
         co_cellvars = load_code_internal(fp, magic_int, code_objects=code_objects)
     else:
@@ -189,240 +192,38 @@ def load_code_type(fp, magic_int, bytes_for_s=False, code_objects={}):
     co_filename = load_code_internal(fp, magic_int, code_objects=code_objects)
     co_name = load_code_internal(fp, magic_int)
 
-    if v15_to_22:
-        co_firstlineno = unpack("<h", fp.read(2))[0]
-    elif v11_to_14:
+    if version >= 1.5:
+        if version >= 2.3:
+            co_firstlineno = unpack("<i", fp.read(4))[0]
+        else:
+            co_firstlineno = unpack("<h", fp.read(2))[0]
+        co_lnotab = load_code_internal(fp, magic_int, code_objects=code_objects)
+    else:
         # < 1.5 there is no lnotab, so no firstlineno.
         # SET_LINENO is used instead.
         co_firstlineno = -1  # Bogus sentinal value
-    else:
-        co_firstlineno = unpack("<i", fp.read(4))[0]
-
-    if v11_to_14:
-        # < 1.5 uses SET_LINENO only
         co_lnotab = ""
-    else:
-        co_lnotab = load_code_internal(fp, magic_int, code_objects=code_objects)
 
-    # The Python3 code object is different than Python2's which
-    # we are reading if we get here.
-    # Also various parameters which were strings are now
-    # bytes (which is probably more logical).
-    if PYTHON3:
-        Code = types.CodeType
-        if PYTHON_MAGIC_INT > 3020 or PYTHON_MAGIC_INT in IS_PYPY3:
-            # Check for Python 3 interpreter reading Python 2 bytecode.
-            # Python 3's code objects are bytes while Python 2's are strings.
-            #
-            # In later Python3 magic_ints, there is a
-            # kwonlyargcount parameter which we set to 0.
-            if v10_to_12 or v13_to_22 or v21_to_27:
-                code = Code2(
-                    co_argcount,
-                    kwonlyargcount,
-                    co_nlocals,
-                    co_stacksize,
-                    co_flags,
-                    co_code,
-                    co_consts,
-                    co_names,
-                    co_varnames,
-                    co_filename,
-                    co_name,
-                    co_firstlineno,
-                    co_lnotab,
-                    co_freevars,
-                    co_cellvars,
-                )
-            else:
-                if PYTHON_MAGIC_INT in (3412, 3413, 3422):
-                    if co_posonlyargcount is not None:
-                        # Python3.8 to Python3.9: Ok to use native Python3.8's code type
-                        code = Code(
-                            co_argcount,
-                            co_posonlyargcount,
-                            kwonlyargcount,
-                            co_nlocals,
-                            co_stacksize,
-                            co_flags,
-                            co_code,
-                            co_consts,
-                            co_names,
-                            co_varnames,
-                            co_filename,
-                            co_name,
-                            co_firstlineno,
-                            bytes(co_lnotab, encoding="utf-8"),
-                            co_freevars,
-                            co_cellvars,
-                        )
-                    else:
-                        if not isinstance(co_lnotab, bytes):
-                            co_lnotab = bytes(co_lnotab, encoding="utf-8")
-                        code = Code3(
-                            co_argcount,
-                            kwonlyargcount,
-                            co_nlocals,
-                            co_stacksize,
-                            co_flags,
-                            co_code,
-                            co_consts,
-                            co_names,
-                            co_varnames,
-                            co_filename,
-                            co_name,
-                            co_firstlineno,
-                            co_lnotab,
-                            co_freevars,
-                            co_cellvars,
-                        )
-                elif co_posonlyargcount is not None:
-                    if not isinstance(co_lnotab, bytes):
-                        co_lnotab = bytes(co_lnotab, encoding="utf-8")
-                    code = Code38(
-                        co_argcount,
-                        co_posonlyargcount,
-                        kwonlyargcount,
-                        co_nlocals,
-                        co_stacksize,
-                        co_flags,
-                        co_code,
-                        co_consts,
-                        co_names,
-                        co_varnames,
-                        co_filename,
-                        co_name,
-                        co_firstlineno,
-                        co_lnotab,
-                        co_freevars,
-                        co_cellvars,
-                    )
+    code = to_portable(
+        co_argcount,
+        co_posonlyargcount,
+        kwonlyargcount,
+        co_nlocals,
+        co_stacksize,
+        co_flags,
+        co_code,
+        co_consts,
+        co_names,
+        co_varnames,
+        co_filename,
+        co_name,
+        co_firstlineno,
+        co_lnotab,
+        co_freevars,
+        co_cellvars,
+        version
+    )
 
-                else:
-                    # Python3 (< 3.8) to Python3: Ok to use native Python3's code type
-                    if not isinstance(co_lnotab, bytes):
-                        co_lnotab = bytes(co_lnotab, encoding="utf-8")
-                    code = Code(
-                        co_argcount,
-                        kwonlyargcount,
-                        co_nlocals,
-                        co_stacksize,
-                        co_flags,
-                        co_code,
-                        co_consts,
-                        co_names,
-                        co_varnames,
-                        co_filename,
-                        co_name,
-                        co_firstlineno,
-                        co_lnotab,
-                        co_freevars,
-                        co_cellvars,
-                    )
-                    pass
-                pass
-        else:
-            code = Code(
-                co_argcount,
-                kwonlyargcount,
-                co_nlocals,
-                co_stacksize,
-                co_flags,
-                co_code,
-                tuple(co_consts),
-                co_names,
-                co_varnames,
-                co_filename,
-                co_name,
-                co_firstlineno,
-                bytes(co_lnotab, encoding="utf-8"),
-                co_freevars,
-                co_cellvars,
-            )
-    else:
-        if v11_to_14:
-            code = Code2Compat(
-                co_argcount,
-                co_nlocals,
-                co_stacksize,
-                co_flags,
-                co_code,
-                co_consts,
-                co_names,
-                co_varnames,
-                co_filename,
-                co_name,
-                co_firstlineno,
-                co_lnotab,
-                co_freevars,
-                co_cellvars,
-            )
-        else:
-            if 3000 <= magic_int < 20121:
-                # Python 3 encodes some fields as Unicode while Python2
-                # requires the corresponding field to have string values
-                co_consts = tuple(
-                    [compat_u2s(s) if isinstance(s, unicode) else s for s in co_consts]
-                )
-                co_names = tuple(
-                    [compat_u2s(s) if isinstance(s, unicode) else s for s in co_names]
-                )
-                co_varnames = tuple(
-                    [
-                        compat_u2s(s) if isinstance(s, unicode) else s
-                        for s in co_varnames
-                    ]
-                )
-                co_filename = str(co_filename)
-                co_name = str(co_name)
-
-            if 3020 < magic_int <= 20121 or magic_int in IS_PYPY3:
-                code = Code3(
-                    co_argcount,
-                    kwonlyargcount,
-                    co_nlocals,
-                    co_stacksize,
-                    co_flags,
-                    co_code,
-                    co_consts,
-                    co_names,
-                    co_varnames,
-                    co_filename,
-                    co_name,
-                    co_firstlineno,
-                    co_lnotab,
-                    co_freevars,
-                    co_cellvars,
-                )
-            else:
-                if magic_int in (160, 192):
-                    co_filename = str(co_filename)
-                    co_name = str(co_name)
-                    co_varnames = tuple([str(t) for t in co_varnames])
-                    co_consts = tuple([str(t) for t in co_consts])
-                    co_freevars = tuple([str(t) for t in co_freevars])
-                    co_cellvars = tuple([str(t) for t in co_cellvars])
-
-                Code = types.CodeType
-                code = Code(
-                    co_argcount,
-                    co_nlocals,
-                    co_stacksize,
-                    co_flags,
-                    co_code,
-                    co_consts,
-                    co_names,
-                    co_varnames,
-                    co_filename,
-                    co_name,
-                    co_firstlineno,
-                    co_lnotab,
-                    co_freevars,
-                    co_cellvars,
-                )
-                pass
-            pass
-        pass
     code_objects[str(code)] = code
     return code
 
